@@ -1,4 +1,4 @@
-#ident "$Header: /cvs/jra1mw/org.glite.lb.server/src/lb_authz.c,v 1.49 2012/04/10 13:55:06 zsustr Exp $"
+#ident "$Header: /cvs/jra1mw/org.glite.lb.server/src/lb_authz.c,v 1.49.2.1 2012/04/30 10:13:20 valtri Exp $"
 /*
 Copyright (c) Members of the EGEE Collaboration. 2004-2010.
 See http://www.eu-egee.org/partners for details on the copyright holders.
@@ -1219,12 +1219,14 @@ check_jobstat_authz(edg_wll_Context ctx,
 	    	    int *authz_flags)
 {
     *authz_flags = 0;
+    if (job_flags & EDG_WLL_NOTIF_ANONYMIZE) *authz_flags |= READ_ANONYMIZED;
+
+    if (ctx->noAuth)
+	return 1;
 
     if (peer == NULL || peer->name == NULL)
 	return 0;
 
-    if (job_flags & EDG_WLL_NOTIF_ANONYMIZE) *authz_flags |= READ_ANONYMIZED;
-
     if (edg_wll_gss_equal_subj(peer->name, stat->owner))
 	return 1;
     if (stat->payload_owner && edg_wll_gss_equal_subj(peer->name, stat->payload_owner))
@@ -1233,8 +1235,7 @@ check_jobstat_authz(edg_wll_Context ctx,
     if ((!(*authz_flags & READ_ANONYMIZED)) && (check_authz_policy(&ctx->authz_policy, peer, READ_ANONYMIZED)))
 	*authz_flags |= READ_ANONYMIZED;
 
-    if (ctx->noAuth ||
-	edg_wll_amIroot(peer->name, peer->fqans, &ctx->authz_policy))
+    if (edg_wll_amIroot(peer->name, peer->fqans, &ctx->authz_policy))
 	return 1;
     if (acl && edg_wll_CheckACL_princ(ctx, acl, EDG_WLL_CHANGEACL_READ, peer) == 0)
 	return 1;
